@@ -2,7 +2,7 @@ from .transforms import resolve
 from .contexts import context
 
 
-class Sigil:
+class Sigil(str):
     """Encapsulate a string that can contain sigils.
     When an instance of this class has its __str__ method called,
     the text gets passed through resolve automatically.
@@ -18,10 +18,9 @@ class Sigil:
     
     def __repr__(self):
         """Return a representation of the sigil."""
-        return f"<Sigil '{self.original}'>"
+        return self.original
 
     def __call__(self, *args, **kwargs):
         """Send all args and kwargs to context, then resolve."""
         with context(*args, **kwargs):
             return resolve(self.original, **self.kwargs)
-
